// Copyright 2018 GRAIL, Inc. All rights reserved.
// Use of this source code is governed by the Apache 2.0
// license that can be found in the LICENSE file.

// THIS FILE WAS AUTOMATICALLY GENERATED. DO NOT EDIT.

package instances

// Type describes an EC2 instance type.
type Type struct {
	// Name is the API name of this EC2 instance type.
	Name string
	// EBSOptimized is set to true if the instance type permits EBS optimization.
	EBSOptimized bool
	// VCPU stores the number of VCPUs provided by this instance type.
	VCPU uint
	// Memory stores the number of (fractional) GiB of memory provided by this instance type.
	Memory float64
	// Price stores the on-demand price per region for this instance type.
	Price map[string]float64
	// Generation stores the generation name for this instance ("current" or "previous").
	Generation string
	// Virt stores the virtualization type used by this instance type.
	Virt string
	// NVMe specifies whether EBS block devices are exposed as NVMe volumes.
	NVMe bool
	// CPUFeatures defines the available CPU features on this instance type
	CPUFeatures map[string]bool
}

// Types stores known EC2 instance types.
var Types = []Type{
	{
		Name:         "cc2.8xlarge",
		EBSOptimized: false,
		VCPU:         32,
		Memory:       60.500000,
		Price: map[string]float64{
			"ap-northeast-1": 2.349,
			"eu-west-1":      2.25,
			"us-east-1":      2,
			"us-gov-west-1":  2.25,
			"us-west-2":      2,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "g2.2xlarge",
		EBSOptimized: false,
		VCPU:         8,
		Memory:       15.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.898,
			"ap-southeast-1": 1,
			"ap-southeast-2": 0.898,
			"eu-central-1":   0.772,
			"eu-west-1":      0.702,
			"us-east-1":      0.65,
			"us-west-1":      0.702,
			"us-west-2":      0.65,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "g2.8xlarge",
		EBSOptimized: false,
		VCPU:         32,
		Memory:       60.000000,
		Price: map[string]float64{
			"ap-northeast-1": 3.592,
			"ap-southeast-1": 4,
			"ap-southeast-2": 3.592,
			"eu-central-1":   3.088,
			"eu-west-1":      2.808,
			"us-east-1":      2.6,
			"us-west-1":      2.808,
			"us-west-2":      2.6,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "cg1.4xlarge",
		EBSOptimized: false,
		VCPU:         16,
		Memory:       22.500000,
		Price: map[string]float64{
			"eu-west-1": 2.36,
			"us-east-1": 2.1,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "cr1.8xlarge",
		EBSOptimized: false,
		VCPU:         32,
		Memory:       244.000000,
		Price: map[string]float64{
			"ap-northeast-1": 4.105,
			"eu-west-1":      3.75,
			"us-east-1":      3.5,
			"us-west-2":      3.5,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i2.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       30.500000,
		Price: map[string]float64{
			"ap-northeast-1": 1.001,
			"ap-northeast-2": 1.001,
			"ap-south-1":     0.967,
			"ap-southeast-1": 1.018,
			"ap-southeast-2": 1.018,
			"eu-central-1":   1.013,
			"eu-west-1":      0.938,
			"us-east-1":      0.853,
			"us-east-2":      0.853,
			"us-gov-west-1":  1.023,
			"us-west-1":      0.938,
			"us-west-2":      0.853,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i2.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       61.000000,
		Price: map[string]float64{
			"ap-northeast-1": 2.001,
			"ap-northeast-2": 2.001,
			"ap-south-1":     1.933,
			"ap-southeast-1": 2.035,
			"ap-southeast-2": 2.035,
			"eu-central-1":   2.026,
			"eu-west-1":      1.876,
			"us-east-1":      1.705,
			"us-east-2":      1.705,
			"us-gov-west-1":  2.046,
			"us-west-1":      1.876,
			"us-west-2":      1.705,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i2.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       122.000000,
		Price: map[string]float64{
			"ap-northeast-1": 4.002,
			"ap-northeast-2": 4.002,
			"ap-south-1":     3.867,
			"ap-southeast-1": 4.07,
			"ap-southeast-2": 4.07,
			"eu-central-1":   4.051,
			"eu-west-1":      3.751,
			"us-east-1":      3.41,
			"us-east-2":      3.41,
			"us-gov-west-1":  4.092,
			"us-west-1":      3.751,
			"us-west-2":      3.41,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i2.8xlarge",
		EBSOptimized: true,
		VCPU:         32,
		Memory:       244.000000,
		Price: map[string]float64{
			"ap-northeast-1": 8.004,
			"ap-northeast-2": 8.004,
			"ap-south-1":     7.733,
			"ap-southeast-1": 8.14,
			"ap-southeast-2": 8.14,
			"eu-central-1":   8.102,
			"eu-west-1":      7.502,
			"us-east-1":      6.82,
			"us-east-2":      6.82,
			"us-gov-west-1":  8.184,
			"us-west-1":      7.502,
			"us-west-2":      6.82,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "hs1.8xlarge",
		EBSOptimized: false,
		VCPU:         16,
		Memory:       117.000000,
		Price: map[string]float64{
			"ap-northeast-1": 5.4,
			"ap-southeast-1": 5.57,
			"ap-southeast-2": 5.57,
			"eu-west-1":      4.9,
			"us-east-1":      4.6,
			"us-gov-west-1":  5.52,
			"us-west-2":      4.6,
		},
		Generation:  "previous",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "t2.nano",
		EBSOptimized: false,
		VCPU:         1,
		Memory:       0.500000,
		Price: map[string]float64{
			"ap-northeast-1": 0.0076,
			"ap-northeast-2": 0.0072,
			"ap-south-1":     0.0062,
			"ap-southeast-1": 0.0073,
			"ap-southeast-2": 0.0073,
			"ca-central-1":   0.0064,
			"eu-central-1":   0.0067,
			"eu-west-1":      0.0063,
			"eu-west-2":      0.0066,
			"eu-west-3":      0.0066,
			"sa-east-1":      0.0093,
			"us-east-1":      0.0058,
			"us-east-2":      0.0058,
			"us-gov-west-1":  0.0068,
			"us-west-1":      0.0069,
			"us-west-2":      0.0058,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "t2.micro",
		EBSOptimized: false,
		VCPU:         1,
		Memory:       1.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.0152,
			"ap-northeast-2": 0.0144,
			"ap-south-1":     0.0124,
			"ap-southeast-1": 0.0146,
			"ap-southeast-2": 0.0146,
			"ca-central-1":   0.0128,
			"eu-central-1":   0.0134,
			"eu-west-1":      0.0126,
			"eu-west-2":      0.0132,
			"eu-west-3":      0.0132,
			"sa-east-1":      0.0186,
			"us-east-1":      0.0116,
			"us-east-2":      0.0116,
			"us-gov-west-1":  0.0136,
			"us-west-1":      0.0138,
			"us-west-2":      0.0116,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "t2.small",
		EBSOptimized: false,
		VCPU:         1,
		Memory:       2.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.0304,
			"ap-northeast-2": 0.0288,
			"ap-south-1":     0.0248,
			"ap-southeast-1": 0.0292,
			"ap-southeast-2": 0.0292,
			"ca-central-1":   0.0256,
			"eu-central-1":   0.0268,
			"eu-west-1":      0.025,
			"eu-west-2":      0.026,
			"eu-west-3":      0.0264,
			"sa-east-1":      0.0372,
			"us-east-1":      0.023,
			"us-east-2":      0.023,
			"us-gov-west-1":  0.0272,
			"us-west-1":      0.0276,
			"us-west-2":      0.023,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "t2.medium",
		EBSOptimized: false,
		VCPU:         2,
		Memory:       4.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.0608,
			"ap-northeast-2": 0.0576,
			"ap-south-1":     0.0496,
			"ap-southeast-1": 0.0584,
			"ap-southeast-2": 0.0584,
			"ca-central-1":   0.0512,
			"eu-central-1":   0.0536,
			"eu-west-1":      0.05,
			"eu-west-2":      0.052,
			"eu-west-3":      0.0528,
			"sa-east-1":      0.0744,
			"us-east-1":      0.0464,
			"us-east-2":      0.0464,
			"us-gov-west-1":  0.0544,
			"us-west-1":      0.0552,
			"us-west-2":      0.0464,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "t2.large",
		EBSOptimized: false,
		VCPU:         2,
		Memory:       8.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.1216,
			"ap-northeast-2": 0.1152,
			"ap-south-1":     0.0992,
			"ap-southeast-1": 0.1168,
			"ap-southeast-2": 0.1168,
			"ca-central-1":   0.1024,
			"eu-central-1":   0.1072,
			"eu-west-1":      0.1008,
			"eu-west-2":      0.1056,
			"eu-west-3":      0.1056,
			"sa-east-1":      0.1488,
			"us-east-1":      0.0928,
			"us-east-2":      0.0928,
			"us-gov-west-1":  0.1088,
			"us-west-1":      0.1104,
			"us-west-2":      0.0928,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "t2.xlarge",
		EBSOptimized: false,
		VCPU:         4,
		Memory:       16.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.2432,
			"ap-northeast-2": 0.2304,
			"ap-south-1":     0.1984,
			"ap-southeast-1": 0.2336,
			"ap-southeast-2": 0.2336,
			"ca-central-1":   0.2048,
			"eu-central-1":   0.2144,
			"eu-west-1":      0.2016,
			"eu-west-2":      0.2112,
			"eu-west-3":      0.2112,
			"sa-east-1":      0.2976,
			"us-east-1":      0.1856,
			"us-east-2":      0.1856,
			"us-gov-west-1":  0.2176,
			"us-west-1":      0.2208,
			"us-west-2":      0.1856,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "t2.2xlarge",
		EBSOptimized: false,
		VCPU:         8,
		Memory:       32.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.4864,
			"ap-northeast-2": 0.4608,
			"ap-south-1":     0.3968,
			"ap-southeast-1": 0.4672,
			"ap-southeast-2": 0.4672,
			"ca-central-1":   0.4096,
			"eu-central-1":   0.4288,
			"eu-west-1":      0.4032,
			"eu-west-2":      0.4224,
			"eu-west-3":      0.4224,
			"sa-east-1":      0.5952,
			"us-east-1":      0.3712,
			"us-east-2":      0.3712,
			"us-gov-west-1":  0.4352,
			"us-west-1":      0.4416,
			"us-west-2":      0.3712,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "m5.large",
		EBSOptimized: true,
		VCPU:         2,
		Memory:       8.000000,
		Price: map[string]float64{
			"eu-west-1": 0.107,
			"eu-west-2": 0.111,
			"eu-west-3": 0.112,
			"us-east-1": 0.096,
			"us-west-1": 0.112,
			"us-west-2": 0.096,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "m5.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       16.000000,
		Price: map[string]float64{
			"eu-west-1": 0.214,
			"eu-west-2": 0.222,
			"eu-west-3": 0.224,
			"us-east-1": 0.192,
			"us-west-1": 0.224,
			"us-west-2": 0.192,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "m5.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       32.000000,
		Price: map[string]float64{
			"eu-west-1": 0.428,
			"eu-west-2": 0.444,
			"eu-west-3": 0.448,
			"us-east-1": 0.384,
			"us-west-1": 0.448,
			"us-west-2": 0.384,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "m5.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       64.000000,
		Price: map[string]float64{
			"eu-west-1": 0.856,
			"eu-west-2": 0.888,
			"eu-west-3": 0.896,
			"us-east-1": 0.768,
			"us-west-1": 0.896,
			"us-west-2": 0.768,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "m5.12xlarge",
		EBSOptimized: true,
		VCPU:         48,
		Memory:       192.000000,
		Price: map[string]float64{
			"eu-west-1": 2.568,
			"eu-west-2": 2.664,
			"eu-west-3": 2.688,
			"us-east-1": 2.304,
			"us-west-1": 2.688,
			"us-west-2": 2.304,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "m5.24xlarge",
		EBSOptimized: true,
		VCPU:         96,
		Memory:       384.000000,
		Price: map[string]float64{
			"eu-west-1": 5.136,
			"eu-west-2": 5.328,
			"eu-west-3": 5.376,
			"us-east-1": 4.608,
			"us-west-1": 5.376,
			"us-west-2": 4.608,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "m4.large",
		EBSOptimized: true,
		VCPU:         2,
		Memory:       8.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.129,
			"ap-northeast-2": 0.123,
			"ap-south-1":     0.105,
			"ap-southeast-1": 0.125,
			"ap-southeast-2": 0.125,
			"ca-central-1":   0.111,
			"eu-central-1":   0.12,
			"eu-west-1":      0.111,
			"eu-west-2":      0.116,
			"sa-east-1":      0.159,
			"us-east-1":      0.1,
			"us-east-2":      0.1,
			"us-gov-west-1":  0.126,
			"us-west-1":      0.117,
			"us-west-2":      0.1,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "m4.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       16.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.258,
			"ap-northeast-2": 0.246,
			"ap-south-1":     0.21,
			"ap-southeast-1": 0.25,
			"ap-southeast-2": 0.25,
			"ca-central-1":   0.222,
			"eu-central-1":   0.24,
			"eu-west-1":      0.222,
			"eu-west-2":      0.232,
			"sa-east-1":      0.318,
			"us-east-1":      0.2,
			"us-east-2":      0.2,
			"us-gov-west-1":  0.252,
			"us-west-1":      0.234,
			"us-west-2":      0.2,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "m4.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       32.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.516,
			"ap-northeast-2": 0.492,
			"ap-south-1":     0.42,
			"ap-southeast-1": 0.5,
			"ap-southeast-2": 0.5,
			"ca-central-1":   0.444,
			"eu-central-1":   0.48,
			"eu-west-1":      0.444,
			"eu-west-2":      0.464,
			"sa-east-1":      0.636,
			"us-east-1":      0.4,
			"us-east-2":      0.4,
			"us-gov-west-1":  0.504,
			"us-west-1":      0.468,
			"us-west-2":      0.4,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "m4.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       64.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.032,
			"ap-northeast-2": 0.984,
			"ap-south-1":     0.84,
			"ap-southeast-1": 1,
			"ap-southeast-2": 1,
			"ca-central-1":   0.888,
			"eu-central-1":   0.96,
			"eu-west-1":      0.888,
			"eu-west-2":      0.928,
			"sa-east-1":      1.272,
			"us-east-1":      0.8,
			"us-east-2":      0.8,
			"us-gov-west-1":  1.008,
			"us-west-1":      0.936,
			"us-west-2":      0.8,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "m4.10xlarge",
		EBSOptimized: true,
		VCPU:         40,
		Memory:       160.000000,
		Price: map[string]float64{
			"ap-northeast-1": 2.58,
			"ap-northeast-2": 2.46,
			"ap-south-1":     2.1,
			"ap-southeast-1": 2.5,
			"ap-southeast-2": 2.5,
			"ca-central-1":   2.22,
			"eu-central-1":   2.4,
			"eu-west-1":      2.22,
			"eu-west-2":      2.32,
			"sa-east-1":      3.18,
			"us-east-1":      2,
			"us-east-2":      2,
			"us-gov-west-1":  2.52,
			"us-west-1":      2.34,
			"us-west-2":      2,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "m4.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       256.000000,
		Price: map[string]float64{
			"ap-northeast-1": 4.128,
			"ap-northeast-2": 3.936,
			"ap-south-1":     3.36,
			"ap-southeast-1": 4,
			"ap-southeast-2": 4,
			"ca-central-1":   3.552,
			"eu-central-1":   3.84,
			"eu-west-1":      3.552,
			"eu-west-2":      3.712,
			"sa-east-1":      5.088,
			"us-east-1":      3.2,
			"us-east-2":      3.2,
			"us-gov-west-1":  4.032,
			"us-west-1":      3.744,
			"us-west-2":      3.2,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "m3.medium",
		EBSOptimized: false,
		VCPU:         1,
		Memory:       3.750000,
		Price: map[string]float64{
			"ap-northeast-1": 0.096,
			"ap-southeast-1": 0.098,
			"ap-southeast-2": 0.093,
			"eu-central-1":   0.079,
			"eu-west-1":      0.073,
			"sa-east-1":      0.095,
			"us-east-1":      0.067,
			"us-gov-west-1":  0.084,
			"us-west-1":      0.077,
			"us-west-2":      0.067,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "m3.large",
		EBSOptimized: false,
		VCPU:         2,
		Memory:       7.500000,
		Price: map[string]float64{
			"ap-northeast-1": 0.193,
			"ap-southeast-1": 0.196,
			"ap-southeast-2": 0.186,
			"eu-central-1":   0.158,
			"eu-west-1":      0.146,
			"sa-east-1":      0.19,
			"us-east-1":      0.133,
			"us-gov-west-1":  0.168,
			"us-west-1":      0.154,
			"us-west-2":      0.133,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "m3.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       15.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.385,
			"ap-southeast-1": 0.392,
			"ap-southeast-2": 0.372,
			"eu-central-1":   0.315,
			"eu-west-1":      0.293,
			"sa-east-1":      0.381,
			"us-east-1":      0.266,
			"us-gov-west-1":  0.336,
			"us-west-1":      0.308,
			"us-west-2":      0.266,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "m3.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       30.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.77,
			"ap-southeast-1": 0.784,
			"ap-southeast-2": 0.745,
			"eu-central-1":   0.632,
			"eu-west-1":      0.585,
			"sa-east-1":      0.761,
			"us-east-1":      0.532,
			"us-gov-west-1":  0.672,
			"us-west-1":      0.616,
			"us-west-2":      0.532,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "c5.large",
		EBSOptimized: true,
		VCPU:         2,
		Memory:       4.000000,
		Price: map[string]float64{
			"eu-west-1": 0.096,
			"eu-west-2": 0.101,
			"eu-west-3": 0.101,
			"us-east-1": 0.085,
			"us-west-1": 0.106,
			"us-west-2": 0.085,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "c5.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       8.000000,
		Price: map[string]float64{
			"eu-west-1": 0.192,
			"eu-west-2": 0.202,
			"eu-west-3": 0.202,
			"us-east-1": 0.17,
			"us-west-1": 0.212,
			"us-west-2": 0.17,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "c5.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       16.000000,
		Price: map[string]float64{
			"eu-west-1": 0.384,
			"eu-west-2": 0.404,
			"eu-west-3": 0.404,
			"us-east-1": 0.34,
			"us-west-1": 0.424,
			"us-west-2": 0.34,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "c5.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       32.000000,
		Price: map[string]float64{
			"eu-west-1": 0.768,
			"eu-west-2": 0.808,
			"eu-west-3": 0.808,
			"us-east-1": 0.68,
			"us-west-1": 0.848,
			"us-west-2": 0.68,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "c5.9xlarge",
		EBSOptimized: true,
		VCPU:         36,
		Memory:       72.000000,
		Price: map[string]float64{
			"eu-west-1": 1.728,
			"eu-west-2": 1.818,
			"eu-west-3": 1.818,
			"us-east-1": 1.53,
			"us-west-1": 1.908,
			"us-west-2": 1.53,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "c5.18xlarge",
		EBSOptimized: true,
		VCPU:         72,
		Memory:       144.000000,
		Price: map[string]float64{
			"eu-west-1": 3.456,
			"eu-west-2": 3.636,
			"eu-west-3": 3.636,
			"us-east-1": 3.06,
			"us-west-1": 3.816,
			"us-west-2": 3.06,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       true,
		CPUFeatures: map[string]bool{
			"intel_avx":    true,
			"intel_avx2":   true,
			"intel_avx512": true,
		},
	},
	{
		Name:         "c4.large",
		EBSOptimized: true,
		VCPU:         2,
		Memory:       3.750000,
		Price: map[string]float64{
			"ap-northeast-1": 0.126,
			"ap-northeast-2": 0.114,
			"ap-south-1":     0.1,
			"ap-southeast-1": 0.115,
			"ap-southeast-2": 0.13,
			"ca-central-1":   0.11,
			"eu-central-1":   0.114,
			"eu-west-1":      0.113,
			"eu-west-2":      0.119,
			"sa-east-1":      0.155,
			"us-east-1":      0.1,
			"us-east-2":      0.1,
			"us-gov-west-1":  0.12,
			"us-west-1":      0.124,
			"us-west-2":      0.1,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "c4.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       7.500000,
		Price: map[string]float64{
			"ap-northeast-1": 0.252,
			"ap-northeast-2": 0.227,
			"ap-south-1":     0.2,
			"ap-southeast-1": 0.231,
			"ap-southeast-2": 0.261,
			"ca-central-1":   0.218,
			"eu-central-1":   0.227,
			"eu-west-1":      0.226,
			"eu-west-2":      0.237,
			"sa-east-1":      0.309,
			"us-east-1":      0.199,
			"us-east-2":      0.199,
			"us-gov-west-1":  0.239,
			"us-west-1":      0.249,
			"us-west-2":      0.199,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "c4.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       15.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.504,
			"ap-northeast-2": 0.454,
			"ap-south-1":     0.4,
			"ap-southeast-1": 0.462,
			"ap-southeast-2": 0.522,
			"ca-central-1":   0.438,
			"eu-central-1":   0.454,
			"eu-west-1":      0.453,
			"eu-west-2":      0.476,
			"sa-east-1":      0.618,
			"us-east-1":      0.398,
			"us-east-2":      0.398,
			"us-gov-west-1":  0.479,
			"us-west-1":      0.498,
			"us-west-2":      0.398,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "c4.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       30.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.008,
			"ap-northeast-2": 0.907,
			"ap-south-1":     0.8,
			"ap-southeast-1": 0.924,
			"ap-southeast-2": 1.042,
			"ca-central-1":   0.876,
			"eu-central-1":   0.909,
			"eu-west-1":      0.905,
			"eu-west-2":      0.95,
			"sa-east-1":      1.235,
			"us-east-1":      0.796,
			"us-east-2":      0.796,
			"us-gov-west-1":  0.958,
			"us-west-1":      0.997,
			"us-west-2":      0.796,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "c4.8xlarge",
		EBSOptimized: true,
		VCPU:         36,
		Memory:       60.000000,
		Price: map[string]float64{
			"ap-northeast-1": 2.016,
			"ap-northeast-2": 1.815,
			"ap-south-1":     1.6,
			"ap-southeast-1": 1.848,
			"ap-southeast-2": 2.085,
			"ca-central-1":   1.75,
			"eu-central-1":   1.817,
			"eu-west-1":      1.811,
			"eu-west-2":      1.902,
			"sa-east-1":      2.47,
			"us-east-1":      1.591,
			"us-east-2":      1.591,
			"us-gov-west-1":  1.915,
			"us-west-1":      1.993,
			"us-west-2":      1.591,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "c3.large",
		EBSOptimized: false,
		VCPU:         2,
		Memory:       3.750000,
		Price: map[string]float64{
			"ap-northeast-1": 0.128,
			"ap-southeast-1": 0.132,
			"ap-southeast-2": 0.132,
			"eu-central-1":   0.129,
			"eu-west-1":      0.12,
			"sa-east-1":      0.163,
			"us-east-1":      0.105,
			"us-gov-west-1":  0.126,
			"us-west-1":      0.12,
			"us-west-2":      0.105,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "c3.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       7.500000,
		Price: map[string]float64{
			"ap-northeast-1": 0.255,
			"ap-southeast-1": 0.265,
			"ap-southeast-2": 0.265,
			"eu-central-1":   0.258,
			"eu-west-1":      0.239,
			"sa-east-1":      0.325,
			"us-east-1":      0.21,
			"us-gov-west-1":  0.252,
			"us-west-1":      0.239,
			"us-west-2":      0.21,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "c3.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       15.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.511,
			"ap-southeast-1": 0.529,
			"ap-southeast-2": 0.529,
			"eu-central-1":   0.516,
			"eu-west-1":      0.478,
			"sa-east-1":      0.65,
			"us-east-1":      0.42,
			"us-gov-west-1":  0.504,
			"us-west-1":      0.478,
			"us-west-2":      0.42,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "c3.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       30.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.021,
			"ap-southeast-1": 1.058,
			"ap-southeast-2": 1.058,
			"eu-central-1":   1.032,
			"eu-west-1":      0.956,
			"sa-east-1":      1.3,
			"us-east-1":      0.84,
			"us-gov-west-1":  1.008,
			"us-west-1":      0.956,
			"us-west-2":      0.84,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "c3.8xlarge",
		EBSOptimized: false,
		VCPU:         32,
		Memory:       60.000000,
		Price: map[string]float64{
			"ap-northeast-1": 2.043,
			"ap-southeast-1": 2.117,
			"ap-southeast-2": 2.117,
			"eu-central-1":   2.064,
			"eu-west-1":      1.912,
			"sa-east-1":      2.6,
			"us-east-1":      1.68,
			"us-gov-west-1":  2.016,
			"us-west-1":      1.912,
			"us-west-2":      1.68,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "x1.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       976.000000,
		Price: map[string]float64{
			"ap-northeast-1": 9.671,
			"ap-northeast-2": 9.671,
			"ap-south-1":     9.187,
			"ap-southeast-1": 9.671,
			"ap-southeast-2": 9.671,
			"ca-central-1":   7.336,
			"eu-central-1":   9.337,
			"eu-west-1":      8.003,
			"eu-west-2":      8.403,
			"eu-west-3":      8.403,
			"sa-east-1":      13.005,
			"us-east-1":      6.669,
			"us-east-2":      6.669,
			"us-gov-west-1":  8.003,
			"us-west-2":      6.669,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "x1.32xlarge",
		EBSOptimized: true,
		VCPU:         128,
		Memory:       1952.000000,
		Price: map[string]float64{
			"ap-northeast-1": 19.341,
			"ap-northeast-2": 19.341,
			"ap-south-1":     18.374,
			"ap-southeast-1": 19.341,
			"ap-southeast-2": 19.341,
			"ca-central-1":   14.672,
			"eu-central-1":   18.674,
			"eu-west-1":      16.006,
			"eu-west-2":      16.806,
			"eu-west-3":      16.806,
			"sa-east-1":      26.01,
			"us-east-1":      13.338,
			"us-east-2":      13.338,
			"us-gov-west-1":  16.006,
			"us-west-2":      13.338,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "x1e.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       122.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.209,
			"ap-southeast-2": 1.209,
			"eu-west-1":      1,
			"us-east-1":      0.834,
			"us-west-2":      0.834,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "x1e.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       244.000000,
		Price: map[string]float64{
			"ap-northeast-1": 2.418,
			"ap-southeast-2": 2.418,
			"eu-west-1":      2,
			"us-east-1":      1.668,
			"us-west-2":      1.668,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "x1e.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       488.000000,
		Price: map[string]float64{
			"ap-northeast-1": 4.836,
			"ap-southeast-2": 4.836,
			"eu-west-1":      4,
			"us-east-1":      3.336,
			"us-west-2":      3.336,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "x1e.8xlarge",
		EBSOptimized: true,
		VCPU:         32,
		Memory:       976.000000,
		Price: map[string]float64{
			"ap-northeast-1": 9.672,
			"ap-southeast-2": 9.672,
			"eu-west-1":      8,
			"us-east-1":      6.672,
			"us-west-2":      6.672,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "x1e.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       1952.000000,
		Price: map[string]float64{
			"ap-northeast-1": 19.344,
			"ap-southeast-2": 19.344,
			"eu-west-1":      16,
			"us-east-1":      13.344,
			"us-west-2":      13.344,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "x1e.32xlarge",
		EBSOptimized: true,
		VCPU:         128,
		Memory:       3904.000000,
		Price: map[string]float64{
			"ap-northeast-1": 38.688,
			"ap-southeast-2": 38.688,
			"eu-west-1":      32,
			"us-east-1":      26.688,
			"us-west-2":      26.688,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "r4.large",
		EBSOptimized: true,
		VCPU:         2,
		Memory:       15.250000,
		Price: map[string]float64{
			"ap-northeast-1": 0.16,
			"ap-northeast-2": 0.16,
			"ap-south-1":     0.137,
			"ap-southeast-1": 0.16,
			"ap-southeast-2": 0.16,
			"ca-central-1":   0.146,
			"eu-central-1":   0.16,
			"eu-west-1":      0.148,
			"eu-west-2":      0.156,
			"eu-west-3":      0.156,
			"sa-east-1":      0.28,
			"us-east-1":      0.133,
			"us-east-2":      0.133,
			"us-gov-west-1":  0.16,
			"us-west-1":      0.148,
			"us-west-2":      0.133,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "r4.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       30.500000,
		Price: map[string]float64{
			"ap-northeast-1": 0.32,
			"ap-northeast-2": 0.32,
			"ap-south-1":     0.274,
			"ap-southeast-1": 0.32,
			"ap-southeast-2": 0.319,
			"ca-central-1":   0.292,
			"eu-central-1":   0.32,
			"eu-west-1":      0.296,
			"eu-west-2":      0.312,
			"eu-west-3":      0.312,
			"sa-east-1":      0.56,
			"us-east-1":      0.266,
			"us-east-2":      0.266,
			"us-gov-west-1":  0.319,
			"us-west-1":      0.296,
			"us-west-2":      0.266,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "r4.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       61.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.64,
			"ap-northeast-2": 0.64,
			"ap-south-1":     0.548,
			"ap-southeast-1": 0.64,
			"ap-southeast-2": 0.638,
			"ca-central-1":   0.584,
			"eu-central-1":   0.64,
			"eu-west-1":      0.593,
			"eu-west-2":      0.624,
			"eu-west-3":      0.624,
			"sa-east-1":      1.12,
			"us-east-1":      0.532,
			"us-east-2":      0.532,
			"us-gov-west-1":  0.638,
			"us-west-1":      0.593,
			"us-west-2":      0.532,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "r4.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       122.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.28,
			"ap-northeast-2": 1.28,
			"ap-south-1":     1.096,
			"ap-southeast-1": 1.28,
			"ap-southeast-2": 1.277,
			"ca-central-1":   1.168,
			"eu-central-1":   1.28,
			"eu-west-1":      1.186,
			"eu-west-2":      1.248,
			"eu-west-3":      1.248,
			"sa-east-1":      2.24,
			"us-east-1":      1.064,
			"us-east-2":      1.064,
			"us-gov-west-1":  1.277,
			"us-west-1":      1.186,
			"us-west-2":      1.064,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "r4.8xlarge",
		EBSOptimized: true,
		VCPU:         32,
		Memory:       244.000000,
		Price: map[string]float64{
			"ap-northeast-1": 2.56,
			"ap-northeast-2": 2.56,
			"ap-south-1":     2.192,
			"ap-southeast-1": 2.56,
			"ap-southeast-2": 2.554,
			"ca-central-1":   2.336,
			"eu-central-1":   2.561,
			"eu-west-1":      2.371,
			"eu-west-2":      2.496,
			"eu-west-3":      2.496,
			"sa-east-1":      4.48,
			"us-east-1":      2.128,
			"us-east-2":      2.128,
			"us-gov-west-1":  2.554,
			"us-west-1":      2.371,
			"us-west-2":      2.128,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "r4.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       488.000000,
		Price: map[string]float64{
			"ap-northeast-1": 5.12,
			"ap-northeast-2": 5.12,
			"ap-south-1":     4.384,
			"ap-southeast-1": 5.12,
			"ap-southeast-2": 5.107,
			"ca-central-1":   4.672,
			"eu-central-1":   5.122,
			"eu-west-1":      4.742,
			"eu-west-2":      4.992,
			"eu-west-3":      4.992,
			"sa-east-1":      8.96,
			"us-east-1":      4.256,
			"us-east-2":      4.256,
			"us-gov-west-1":  5.107,
			"us-west-1":      4.742,
			"us-west-2":      4.256,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "r3.large",
		EBSOptimized: false,
		VCPU:         2,
		Memory:       15.250000,
		Price: map[string]float64{
			"ap-northeast-1": 0.2,
			"ap-northeast-2": 0.2,
			"ap-south-1":     0.19,
			"ap-southeast-1": 0.2,
			"ap-southeast-2": 0.2,
			"eu-central-1":   0.2,
			"eu-west-1":      0.185,
			"sa-east-1":      0.35,
			"us-east-1":      0.166,
			"us-east-2":      0.166,
			"us-gov-west-1":  0.2,
			"us-west-1":      0.185,
			"us-west-2":      0.166,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "r3.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       30.500000,
		Price: map[string]float64{
			"ap-northeast-1": 0.399,
			"ap-northeast-2": 0.399,
			"ap-south-1":     0.379,
			"ap-southeast-1": 0.399,
			"ap-southeast-2": 0.399,
			"eu-central-1":   0.4,
			"eu-west-1":      0.371,
			"sa-east-1":      0.7,
			"us-east-1":      0.333,
			"us-east-2":      0.333,
			"us-gov-west-1":  0.399,
			"us-west-1":      0.371,
			"us-west-2":      0.333,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "r3.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       61.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.798,
			"ap-northeast-2": 0.798,
			"ap-south-1":     0.758,
			"ap-southeast-1": 0.798,
			"ap-southeast-2": 0.798,
			"eu-central-1":   0.8,
			"eu-west-1":      0.741,
			"sa-east-1":      1.399,
			"us-east-1":      0.665,
			"us-east-2":      0.665,
			"us-gov-west-1":  0.798,
			"us-west-1":      0.741,
			"us-west-2":      0.665,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "r3.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       122.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.596,
			"ap-northeast-2": 1.596,
			"ap-south-1":     1.516,
			"ap-southeast-1": 1.596,
			"ap-southeast-2": 1.596,
			"eu-central-1":   1.6,
			"eu-west-1":      1.482,
			"sa-east-1":      2.799,
			"us-east-1":      1.33,
			"us-east-2":      1.33,
			"us-gov-west-1":  1.596,
			"us-west-1":      1.482,
			"us-west-2":      1.33,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "r3.8xlarge",
		EBSOptimized: false,
		VCPU:         32,
		Memory:       244.000000,
		Price: map[string]float64{
			"ap-northeast-1": 3.192,
			"ap-northeast-2": 3.192,
			"ap-south-1":     3.032,
			"ap-southeast-1": 3.192,
			"ap-southeast-2": 3.192,
			"eu-central-1":   3.201,
			"eu-west-1":      2.964,
			"sa-east-1":      5.597,
			"us-east-1":      2.66,
			"us-east-2":      2.66,
			"us-gov-west-1":  3.192,
			"us-west-1":      2.964,
			"us-west-2":      2.66,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx": true,
		},
	},
	{
		Name:         "p3.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       61.000000,
		Price: map[string]float64{
			"ap-northeast-1": 5.243,
			"ap-northeast-2": 4.981,
			"eu-west-1":      3.305,
			"us-east-1":      3.06,
			"us-east-2":      3.06,
			"us-gov-west-1":  3.672,
			"us-west-2":      3.06,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "p3.8xlarge",
		EBSOptimized: true,
		VCPU:         32,
		Memory:       244.000000,
		Price: map[string]float64{
			"ap-northeast-1": 20.972,
			"ap-northeast-2": 19.924,
			"eu-west-1":      13.22,
			"us-east-1":      12.24,
			"us-east-2":      12.24,
			"us-gov-west-1":  14.688,
			"us-west-2":      12.24,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "p3.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       488.000000,
		Price: map[string]float64{
			"ap-northeast-1": 41.944,
			"ap-northeast-2": 39.848,
			"eu-west-1":      26.44,
			"us-east-1":      24.48,
			"us-east-2":      24.48,
			"us-gov-west-1":  29.376,
			"us-west-2":      24.48,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "p2.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       61.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.542,
			"ap-northeast-2": 1.465,
			"ap-south-1":     1.718,
			"ap-southeast-1": 1.718,
			"ap-southeast-2": 1.542,
			"eu-central-1":   1.326,
			"eu-west-1":      0.972,
			"us-east-1":      0.9,
			"us-east-2":      0.9,
			"us-gov-west-1":  1.08,
			"us-west-2":      0.9,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "p2.8xlarge",
		EBSOptimized: true,
		VCPU:         32,
		Memory:       488.000000,
		Price: map[string]float64{
			"ap-northeast-1": 12.336,
			"ap-northeast-2": 11.72,
			"ap-south-1":     13.744,
			"ap-southeast-1": 13.744,
			"ap-southeast-2": 12.336,
			"eu-central-1":   10.608,
			"eu-west-1":      7.776,
			"us-east-1":      7.2,
			"us-east-2":      7.2,
			"us-gov-west-1":  8.64,
			"us-west-2":      7.2,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "p2.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       732.000000,
		Price: map[string]float64{
			"ap-northeast-1": 24.672,
			"ap-northeast-2": 23.44,
			"ap-south-1":     27.488,
			"ap-southeast-1": 27.488,
			"ap-southeast-2": 24.672,
			"eu-central-1":   21.216,
			"eu-west-1":      15.552,
			"us-east-1":      14.4,
			"us-east-2":      14.4,
			"us-gov-west-1":  17.28,
			"us-west-2":      14.4,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "g3.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       122.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.58,
			"ap-southeast-1": 1.67,
			"ap-southeast-2": 1.754,
			"eu-central-1":   1.425,
			"eu-west-1":      1.21,
			"us-east-1":      1.14,
			"us-east-2":      1.14,
			"us-gov-west-1":  1.32,
			"us-west-1":      1.534,
			"us-west-2":      1.14,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "g3.8xlarge",
		EBSOptimized: true,
		VCPU:         32,
		Memory:       244.000000,
		Price: map[string]float64{
			"ap-northeast-1": 3.16,
			"ap-southeast-1": 3.34,
			"ap-southeast-2": 3.508,
			"eu-central-1":   2.85,
			"eu-west-1":      2.42,
			"us-east-1":      2.28,
			"us-east-2":      2.28,
			"us-gov-west-1":  2.64,
			"us-west-1":      3.068,
			"us-west-2":      2.28,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "g3.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       488.000000,
		Price: map[string]float64{
			"ap-northeast-1": 6.32,
			"ap-southeast-1": 6.68,
			"ap-southeast-2": 7.016,
			"eu-central-1":   5.7,
			"eu-west-1":      4.84,
			"us-east-1":      4.56,
			"us-east-2":      4.56,
			"us-gov-west-1":  5.28,
			"us-west-1":      6.136,
			"us-west-2":      4.56,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "f1.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       122.000000,
		Price: map[string]float64{
			"eu-west-1":     1.815,
			"us-east-1":     1.65,
			"us-gov-west-1": 1.98,
			"us-west-2":     1.65,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "f1.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       976.000000,
		Price: map[string]float64{
			"eu-west-1":     14.52,
			"us-east-1":     13.2,
			"us-gov-west-1": 15.84,
			"us-west-2":     13.2,
		},
		Generation: "current",
		Virt:       "HVM",
		NVMe:       false,
		CPUFeatures: map[string]bool{
			"intel_avx":  true,
			"intel_avx2": true,
		},
	},
	{
		Name:         "h1.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       32.000000,
		Price: map[string]float64{
			"eu-west-1": 0.611,
			"us-east-1": 0.55,
			"us-east-2": 0.55,
			"us-west-2": 0.55,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "h1.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       64.000000,
		Price: map[string]float64{
			"eu-west-1": 1.222,
			"us-east-1": 1.1,
			"us-east-2": 1.1,
			"us-west-2": 1.1,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "h1.8xlarge",
		EBSOptimized: true,
		VCPU:         32,
		Memory:       128.000000,
		Price: map[string]float64{
			"eu-west-1": 2.444,
			"us-east-1": 2.2,
			"us-east-2": 2.2,
			"us-west-2": 2.2,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "h1.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       256.000000,
		Price: map[string]float64{
			"eu-west-1": 4.888,
			"us-east-1": 4.4,
			"us-east-2": 4.4,
			"us-west-2": 4.4,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i3.large",
		EBSOptimized: true,
		VCPU:         2,
		Memory:       15.250000,
		Price: map[string]float64{
			"ap-northeast-1": 0.183,
			"ap-northeast-2": 0.183,
			"ap-south-1":     0.177,
			"ap-southeast-1": 0.187,
			"ap-southeast-2": 0.187,
			"ca-central-1":   0.172,
			"eu-central-1":   0.186,
			"eu-west-1":      0.172,
			"eu-west-2":      0.181,
			"eu-west-3":      0.181,
			"sa-east-1":      0.286,
			"us-east-1":      0.156,
			"us-east-2":      0.156,
			"us-gov-west-1":  0.188,
			"us-west-1":      0.172,
			"us-west-2":      0.156,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i3.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       30.500000,
		Price: map[string]float64{
			"ap-northeast-1": 0.366,
			"ap-northeast-2": 0.366,
			"ap-south-1":     0.354,
			"ap-southeast-1": 0.374,
			"ap-southeast-2": 0.374,
			"ca-central-1":   0.344,
			"eu-central-1":   0.372,
			"eu-west-1":      0.344,
			"eu-west-2":      0.362,
			"eu-west-3":      0.362,
			"sa-east-1":      0.572,
			"us-east-1":      0.312,
			"us-east-2":      0.312,
			"us-gov-west-1":  0.376,
			"us-west-1":      0.344,
			"us-west-2":      0.312,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i3.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       61.000000,
		Price: map[string]float64{
			"ap-northeast-1": 0.732,
			"ap-northeast-2": 0.732,
			"ap-south-1":     0.708,
			"ap-southeast-1": 0.748,
			"ap-southeast-2": 0.748,
			"ca-central-1":   0.688,
			"eu-central-1":   0.744,
			"eu-west-1":      0.688,
			"eu-west-2":      0.724,
			"eu-west-3":      0.724,
			"sa-east-1":      1.144,
			"us-east-1":      0.624,
			"us-east-2":      0.624,
			"us-gov-west-1":  0.752,
			"us-west-1":      0.688,
			"us-west-2":      0.624,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i3.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       122.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.464,
			"ap-northeast-2": 1.464,
			"ap-south-1":     1.416,
			"ap-southeast-1": 1.496,
			"ap-southeast-2": 1.496,
			"ca-central-1":   1.376,
			"eu-central-1":   1.488,
			"eu-west-1":      1.376,
			"eu-west-2":      1.448,
			"eu-west-3":      1.448,
			"sa-east-1":      2.288,
			"us-east-1":      1.248,
			"us-east-2":      1.248,
			"us-gov-west-1":  1.504,
			"us-west-1":      1.376,
			"us-west-2":      1.248,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i3.8xlarge",
		EBSOptimized: true,
		VCPU:         32,
		Memory:       244.000000,
		Price: map[string]float64{
			"ap-northeast-1": 2.928,
			"ap-northeast-2": 2.928,
			"ap-south-1":     2.832,
			"ap-southeast-1": 2.992,
			"ap-southeast-2": 2.992,
			"ca-central-1":   2.752,
			"eu-central-1":   2.976,
			"eu-west-1":      2.752,
			"eu-west-2":      2.896,
			"eu-west-3":      2.896,
			"sa-east-1":      4.576,
			"us-east-1":      2.496,
			"us-east-2":      2.496,
			"us-gov-west-1":  3.008,
			"us-west-1":      2.752,
			"us-west-2":      2.496,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "i3.16xlarge",
		EBSOptimized: true,
		VCPU:         64,
		Memory:       488.000000,
		Price: map[string]float64{
			"ap-northeast-1": 5.856,
			"ap-northeast-2": 5.856,
			"ap-south-1":     5.664,
			"ap-southeast-1": 5.984,
			"ap-southeast-2": 5.984,
			"ca-central-1":   5.504,
			"eu-central-1":   5.952,
			"eu-west-1":      5.504,
			"eu-west-2":      5.792,
			"eu-west-3":      5.792,
			"sa-east-1":      9.152,
			"us-east-1":      4.992,
			"us-east-2":      4.992,
			"us-gov-west-1":  6.016,
			"us-west-1":      5.504,
			"us-west-2":      4.992,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "d2.xlarge",
		EBSOptimized: true,
		VCPU:         4,
		Memory:       30.500000,
		Price: map[string]float64{
			"ap-northeast-1": 0.844,
			"ap-northeast-2": 0.844,
			"ap-south-1":     0.827,
			"ap-southeast-1": 0.87,
			"ap-southeast-2": 0.87,
			"ca-central-1":   0.759,
			"eu-central-1":   0.794,
			"eu-west-1":      0.735,
			"eu-west-2":      0.772,
			"eu-west-3":      0.772,
			"us-east-1":      0.69,
			"us-east-2":      0.69,
			"us-gov-west-1":  0.828,
			"us-west-1":      0.781,
			"us-west-2":      0.69,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "d2.2xlarge",
		EBSOptimized: true,
		VCPU:         8,
		Memory:       61.000000,
		Price: map[string]float64{
			"ap-northeast-1": 1.688,
			"ap-northeast-2": 1.688,
			"ap-south-1":     1.653,
			"ap-southeast-1": 1.74,
			"ap-southeast-2": 1.74,
			"ca-central-1":   1.518,
			"eu-central-1":   1.588,
			"eu-west-1":      1.47,
			"eu-west-2":      1.544,
			"eu-west-3":      1.544,
			"us-east-1":      1.38,
			"us-east-2":      1.38,
			"us-gov-west-1":  1.656,
			"us-west-1":      1.563,
			"us-west-2":      1.38,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "d2.4xlarge",
		EBSOptimized: true,
		VCPU:         16,
		Memory:       122.000000,
		Price: map[string]float64{
			"ap-northeast-1": 3.376,
			"ap-northeast-2": 3.376,
			"ap-south-1":     3.306,
			"ap-southeast-1": 3.48,
			"ap-southeast-2": 3.48,
			"ca-central-1":   3.036,
			"eu-central-1":   3.176,
			"eu-west-1":      2.94,
			"eu-west-2":      3.087,
			"eu-west-3":      3.088,
			"us-east-1":      2.76,
			"us-east-2":      2.76,
			"us-gov-west-1":  3.312,
			"us-west-1":      3.125,
			"us-west-2":      2.76,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
	{
		Name:         "d2.8xlarge",
		EBSOptimized: true,
		VCPU:         36,
		Memory:       244.000000,
		Price: map[string]float64{
			"ap-northeast-1": 6.752,
			"ap-northeast-2": 6.752,
			"ap-south-1":     6.612,
			"ap-southeast-1": 6.96,
			"ap-southeast-2": 6.96,
			"ca-central-1":   6.072,
			"eu-central-1":   6.352,
			"eu-west-1":      5.88,
			"eu-west-2":      6.174,
			"eu-west-3":      6.176,
			"us-east-1":      5.52,
			"us-east-2":      5.52,
			"us-gov-west-1":  6.624,
			"us-west-1":      6.25,
			"us-west-2":      5.52,
		},
		Generation:  "current",
		Virt:        "HVM",
		NVMe:        false,
		CPUFeatures: map[string]bool{},
	},
}
